camelot.camelot.view.controls.inheritance.SubclassItem

Package camelot :: Package camelot :: Package view :: Package controls :: Module inheritance :: Class SubclassItem |
[hide private]
[frames] | no frames]

# Class SubclassItem

source code

Instance Methods | [hide private]
__init__(self, parent, admin) | source code
Inherited from `modeltree.ModelItem`: `set_icon` Inherited from `modeltree.ModelItem` (private): `_underline`

Method Details | [hide private]

### __init__(self, parent, admin) (Constructor) | source code
Overrides: modeltree.ModelItem.__init__